pub fn ceil_pow2(n: u32) -> u32Expand description
Round n up to the nearest power of 2. 0 and 1 both return
1. Used to derive a GPU.7 GridUpload::pool_dims from a
non-pow2 chunks_dims.
pub fn ceil_pow2(n: u32) -> u32Round n up to the nearest power of 2. 0 and 1 both return
1. Used to derive a GPU.7 GridUpload::pool_dims from a
non-pow2 chunks_dims.